% Process_and_Plot_Building_America_Climate_Regions_2015.m
% 20200115
% Casey D. Burleyson
% Pacific Northwest National Laboratory
% Create maps of the eight building america climate regions.

warning off all; clear all; close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN USER INPUT SECTION               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set processing and plotting flags:
process_data = 1; % (1 = yes)
save_images = 1; % (1 = yes)

% Set the data input and output directories:
data_input_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/Building_America_Climate_Regions_2015/';
data_output_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/Building_America_Climate_Regions_2015/';
image_output_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/Building_America_Climate_Regions_2015/Figures/';

% Set the geographic boundaries on the plots:
lat_min = 24.75;
lat_max = 49.75;
lon_min = -125;
lon_max = -66.5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              END USER INPUT SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN PROCESSING SECTION               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if process_data == 1
   load([data_input_dir,'Code/shapefile_counties.mat'],'shapefile_counties');
   for row = 1:size(shapefile_counties,1)
       county_FIPS_vector(row,1) = shapefile_counties(row,1).county_FIPS;
   end
   clear row
    
   [~,~,County_Raw] = xlsread([data_input_dir,'county_building_america_climate_regions_2015.xlsx'],'Counties','A1:E3144');
   for row = 2:size(County_Raw,1)
       County_Mapping(row-1,1) = County_Raw{row,3};
       County_Mapping(row-1,2) = County_Raw{row,5};
   end
   County_Mapping = County_Mapping(find(County_Mapping(:,1) ~= 11000),:);
   clear row County_Raw
      
   for row = 1:size(County_Mapping,1)
       index = find(county_FIPS_vector(:) == County_Mapping(row,1));
       County_Mapping(row,3) = index;
       clear index
   end
   clear row county_FIPS_vector
   
   save([data_output_dir,'county_building_america_climate_regions_2015.mat'],'County_Mapping','shapefile_counties');
else
   load([data_output_dir,'county_building_america_climate_regions_2015.mat']);
end 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               END PROCESSING SECTION                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN PLOTTING SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
a = figure('Color',[1 1 1]); set(a,'Position',get(0,'Screensize')); hold on;
ax1 = usamap([lat_min lat_max],[lon_min lon_max]); colormap(ax1,jet(7));
states = shaperead('usastatelo','UseGeoCoords',true,'Selector',{@(name)~any(strcmp(name,{'Alaska','Hawaii'})),'Name'});
faceColors = makesymbolspec('Polygon',{'INDEX',[1 numel(states)],'FaceColor',polcmap(numel(states))}); faceColors.FaceColor{1,3} = faceColors.FaceColor{1,3}./faceColors.FaceColor{1,3};
geoshow(ax1,states,'DisplayType','polygon','SymbolSpec',faceColors,'LineWidth',1,'LineStyle','-');
for row = 1:size(County_Mapping,1)
    patchm(shapefile_counties(County_Mapping(row,3),1).lat_vector,shapefile_counties(County_Mapping(row,3),1).lon_vector,0,'FaceVertexCData',County_Mapping(row,2),'FaceColor','flat');
end
set(gca,'clim',[1.5 8.5]);
colo1 = colorbar('xtick',[2:1:8],'xTickLabel',{'Very Cold','Cold','Marine','Mixed-Humid','Hot-Humid','Mixed-Dry','Hot-Dry'},'Location','SouthOutside');
tightmap; framem on; gridm off; mlabel off; plabel off;
set(gca,'LineWidth',3,'FontSize',21,'Box','on','Layer','top');
title(['2015 Building America Climate Regions'],'FontSize',24);
if save_images == 1
   set(gcf,'Renderer','zbuffer'); set(gcf,'PaperPositionMode','auto');
   print(a,'-dpng','-r300',[image_output_dir,'County_Building_America_Climate_Regions_2015.png']);
   close(a);
end
clear a ax1 colo1 row faceColors states
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               END PLOTTING SECTION                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                BEGIN CLEANUP SECTION                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear data_input_dir image_output_dir save_images lat_min lat_max lon_min lon_max process_data data_output_dir shapefile_counties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 END CLEANUP SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%